.. bricklane documentation master file, created by
   sphinx-quickstart on Mon Jan  6 07:46:09 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Bagel Documentation
==================

Welcome to the Bagel package documentation.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/modules

API Reference
------------

.. automodule:: bagel
   :members:
   :undoc-members:
   :show-inheritance:

Core Modules
-----------

.. automodule:: bagel.chain
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.system
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.energies
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.state
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.mutation
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.minimizer
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: bagel.constants
   :members:
   :undoc-members:
   :show-inheritance:

Folding Package
-------------

.. automodule:: bagel.folding
   :members:
   :undoc-members:
   :show-inheritance:
